//==============================================================================
// PROJECT      = H_Line Demonstration Board EB-V850ES/HG2-EE (Electronic Dice)
// MODULE       = dice.c
// SHORT DESC.  = -
// DEVICE       = V850ES/HG2 (uPD70F3707)
// VERSION      = 1.0
// DATE         = 08.11.2005
// LAST CHANGE  = -
// =============================================================================
// Description:  Electronic Dice
//               After initialization the 7seg LED flashes twice.
//               After pressing KeySW1 the electronic dice starts and the
//               throwed number is displayed by the 7seg LEDs.
//               Then the program waits for the next key stroke.
//
// =============================================================================
// By:          NEC Electronics (Europe) GmbH
//              Arcadiastrasse 10
//              D-40472 Duesseldorf
//
// =============================================================================


//-----------------------------------------------------------------------------
// Defines
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Include files
//-----------------------------------------------------------------------------
#include "defines.h"

#include <intrinsics.h>
#include "io70f3707.h"

//-----------------------------------------------------------------------------
// Function prototyps
//-----------------------------------------------------------------------------
       void          vFlashLED      (unsigned char);// flash all LEDs n times
       void          vWait25        (unsigned char);// n *  25ms delay
       unsigned char ucRandom       (void);         // generation of random-number
extern void          vHardwareInit  (void);         // initialization Hardware
extern void          vSoftwareInit  (void);         // initialization of variables

//-----------------------------------------------------------------------------
// Global variables
//-----------------------------------------------------------------------------
volatile unsigned char bTimer3Flag;                    // status Flag 16Bit Timer three
volatile unsigned char bTimer2Flag;                    // status Flag 16Bit Timer two
volatile unsigned char bKeySW1Flag;                    // status Flag KeySW1
unsigned char ucThrow;                                 // dice value

// ============================================================================
//  Module name: LED_segout
//
//  Description:
//               Generates output pattern for 7 seg. LED
//
// ============================================================================
unsigned char LED_segout(unsigned char binary)
{
    const unsigned char tab[6]={0xf9,0xa4,0xb0,0x99,0x92,0x82};
    return tab[binary];
}

// ============================================================================
//  Module name: ucRandom
//
//  Description:
//               This module generates a pseudo-random number.
//
//  Operation:
//               -
// ============================================================================

unsigned char ucRandom(void)
{
    return (TP0CNT % 6)+ 1;             // pseudo-random number between 1 ... 6
}


// ============================================================================
//  Module name: vFlashLED
//
//  Description:
//               This module flashes all LEDs n times.
//
//  Operation:
//               -
// ============================================================================

void vFlashLED(unsigned char Number)
{
    while(Number>0) {
       P9L = 0x00;                    // all LEDs on
       vWait25(20);                   // delay of 500 ms
       P9L = 0xff;                    // all LEDs off
       vWait25(20);                   // delay of 500 ms
       Number--;
    }
    return;
}


// ============================================================================
//  Module name: vWait25
//
//  Description:
//               This module delays the program for n * 25 ms.
//
//  Operation:
//               -
// ============================================================================

void vWait25(unsigned char Number)
{
    bTimer2Flag = FALSE;               // reset flag 16bit Timer two
    STARTTIMER2;                       // start 16 bit Timer two
    while(Number>0) {
        while(bTimer2Flag == FALSE){   // wait for Timer Interrupt
          __NOP();
          __NOP();
        }
        TRIGGERWD;                     // trigger watchdog
        bTimer2Flag = FALSE;           // reset flag 16bit Timer two
        Number--;
    }
    STOPTIMER2;                        // stop 16bit Timer two
    return;
}


// ============================================================================
//  main function
// ============================================================================

void main( void )
{
    unsigned char i;
    WDTE = 0xAC;                       // trigger watchdog
    __DI();                            // disable all interrupts
    vHardwareInit();                   // peripheral settings
    vSoftwareInit();                   // variable Initialization
    STARTTIMER1;                       // start 16 bit Timer one
    __EI();                            // enable all interrupts
    vFlashLED(2);                      // signal: end of initialization
    while(TRUE)
    {
       TRIGGERWD;                      // trigger watchdog
       if(bKeySW1Flag==1){
         bKeySW1Flag=0;                // reset status key1
         ucThrow=ucRandom()-1;         // get random number
         for(i=0;i<5;i++){             // animation loop
             if( (i+ucThrow) < 5) {
                  P9L = LED_segout(i+ucThrow);
             }
             else if ((i-ucThrow) > 0){
                  P9L = LED_segout(i-ucThrow);
             }
             else {
                  P9L = LED_segout(i);
            }
             vWait25(4+(2*i));          // delay of (100 + i * 50) ms
             TRIGGERWD;                 // trigger watchdog
         }
         P9L = LED_segout(ucThrow);     // output of new value
       }
    }
}
