//==============================================================================
// PROJECT      = H_Line Demonstration Board EB-V850ES/HG2-EE (Electronic Dice)
// MODULE       = dice.c
// SHORT DESC.  = -
// DEVICE       = V850ES/HG2 (uPD70F3707)
// VERSION      = 1.0
// DATE         = 08.11.2005
// LAST CHANGE  = -
// =============================================================================
// Description:  Electronic Dice
//               After initialization all LEDs flash twice
//               After pressing Key SW2, one to six LEDs get switched on.
//               Then the program waits for the next start.
//
// =============================================================================
// By:          NEC Electronics (Europe) GmbH
//              Arcadiastrasse 10
//              D-40472 Duesseldorf
//
// =============================================================================

//-----------------------------------------------------------------------------
// Defines
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Include files
//-----------------------------------------------------------------------------
#include "defines.h"

#include <intrinsics.h>
#include "io70f3707.h"

//-----------------------------------------------------------------------------
// Global variables
//-----------------------------------------------------------------------------
extern volatile unsigned char bTimer3Flag;      // Status Flag 16bit Timer three
extern volatile unsigned char bTimer2Flag;      // Status Flag 16bit Timer two
extern volatile unsigned char bKeySW1Flag;      // Status Flag KeySW1

// ============================================================================
//  Module name: vTimer1
//
//  Description:
//               This module is the Interrupt service routine or 16bit Timer two
//
//  Operation:
//               -
// ============================================================================

#pragma vector = INTTP1CC0_vector
__flat __interrupt void vTimer1 (void)
{
    bTimer2Flag = 1 ;                   // Set status flag Timer two
}


// ============================================================================
//  Module name: vTimer2
//
//  Description:
//               This module is the Interrupt service routine for Timer2
//
//  Operation:
//               -
// ============================================================================

#pragma vector = INTTP2CC0_vector
__flat __interrupt void vTimer2 (void)
{
    bTimer3Flag = 1 ;                   // Set status flag Timer three
}


// ============================================================================
//  Module name: vKeySW1
//
//  Description:
//               This module is the Interrupt service routine for
//               the external interrupt P1 (-> KeySW1)
//
//  Operation:
//               -
// ============================================================================

#pragma vector = INTP1_vector
__flat __interrupt void vKeySW1(void)
{
    bKeySW1Flag = 1 ;                     // Set status flag keySW1
}
