//==============================================================================
// PROJECT      = H_Line Demonstration Board EB-V850ES/HG2-EE (Code Checker)
// MODULE       = codechecker.c
// SHORT DESC.  = -
// DEVICE       = V850ES/HG2 (uPD70F3707)
// VERSION      = 1.0
// DATE         = 08.11.2005
// LAST CHANGE  = -
// ===========================================================================
// Description:  Entrance code checker
//               The board waits for a predefined sequence of keystrokes
//               (e.g. keySW1-keySW1-keySW2-keySW1-keySW2) and switches the 7seg LED
//               to 'O' and an external port on for 5 s. If the input sequence doesn't
//               match the correct sequence the 7seg LED flashes 'F' five times.
//               After that the program restart and waits for a new input sequence.
// ===========================================================================
// By:           NEC Electronics (Europe) GmbH
//               Arcadiastrasse 10
//               D-40472 Duesseldorf
//
// =============================================================================

//-----------------------------------------------------------------------------
// Defines
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Include files
//-----------------------------------------------------------------------------
#include "defines.h"

#include <intrinsics.h>
#include "io70f3707.h"


//-----------------------------------------------------------------------------
// Function prototyps
//-----------------------------------------------------------------------------
       void   vFlashLED      (unsigned char);      // Flash uiLEDs's
       void   vWait25        (unsigned int);       // n *  25ms delay
       void   vRestartT2     (void);               // Restart Timer2
extern void   vHardwareInit  (void);               // Initialization Hardware
extern void   vSoftwareInit  (void);               // Initialization measurement variables

//-----------------------------------------------------------------------------
// Global variables
//-----------------------------------------------------------------------------
volatile  unsigned char bTimer2Flag;               // Status Flag Timer2
volatile  unsigned char bKeySW1Flag;               // Status Flag Key3
volatile  unsigned char bKeySW2Flag;               // Status Flag Key2
const     unsigned char ucCode[5]  = {1,1,2,1,2};  // Keystroke sequence
          unsigned int  uiLEDs;                    // LED output
          unsigned char ucInput[5];                // Input sequence

// ============================================================================
//  Module name: LED_segout
//
//  Description:
//               Generates output pattern for 7 seg. LED
//
// ============================================================================
unsigned char LED_segout(unsigned char binary)
{
    const unsigned char tab[16]={0xC0,0xf9,0xa4,0xb0,0x99,0x92,0x82,0xf8,0x80,0x90,0x88,0x83,0xc6,0xa1,0x86,0x8e};
    return tab[binary];
}

// ============================================================================
//  Module name: vFlashLED
//
//  Description:
//               This module flashes all LEDs n times.
//
//  Operation:
//               -
// ============================================================================

void vFlashLED(unsigned char Number)
{
    while(Number>0) {
       P9L = 0x00;                   // all LEDs on
       vWait25(40);                  // delay of 1 s
       P9L = 0xff;                   // all LEDs off
       vWait25(40);                  // delay of 1 s
       Number--;
    }
    return;
}


// ============================================================================
//  Module name: vWait25
//
//  Description:
//               This module delays the program for n * 25 ms.
//
//  Operation:
//               -
// ============================================================================

void vWait25(unsigned int Number)
{
  bTimer2Flag = FALSE;                 // reset status flag Timer2
  STARTTIMER2;
  while(Number > 0) {
         while(bTimer2Flag == FALSE){  // wait for Timer Interrupt
          __NOP();
          __NOP();
        }
        bTimer2Flag = FALSE;           // reset status flag Timer2
        Number--;
        TRIGGERWD;                     // trigger watchdog
  }
  STOPTIMER2;
  return;
}



// ============================================================================
//  main function
// ============================================================================

void main( void )
{
    unsigned char i=0;
    __DI();                            // Disable all interrupts
    vHardwareInit();                   // Peripheral settings
    vSoftwareInit();                   // Variable Initialization
    __EI();                            // Enable all interrupts
    while(TRUE)
    {
       vFlashLED(2);                   // Signal Program start
       TRIGGERWD;                      // trigger watchdog
       while (i<5){                    // Get input sequence
          TRIGGERWD;                   // trigger watchdog
          if((bKeySW1Flag == TRUE) || (bKeySW2Flag == TRUE)){
              if (bKeySW1Flag == TRUE){
                P9L = LED_segout(1);   // Feedback for keystroke
                vWait25(20);           // Delay of 500 ms
                P9L = 0xff;            // Feedback for keystroke
                ucInput[i] = 1;
                bKeySW1Flag  = FALSE;
              }
              else{
                P9L = LED_segout(2);   // Feedback for keystroke
                vWait25(20);           // Delay of 500 ms
                P9L = 0xff;            // Feedback for keystroke
                ucInput[i] = 2;
                bKeySW2Flag  = FALSE;
              }
              i++;                     // count of Keystrokes
          }
       }
       i=0;
       while (i<5){                    // Compare input with code sequence
          if (ucCode[i] != ucInput[i])
          {
            i = 10;                    // wrong sequence
          }
          else
          {
            i++;                       // correct keystroke
          }
       }
       if (i == 5){                    // correct sequence
          P9L    = LED_segout(0);      // Feedback for correct sequence
          OUT    = TRUE;               // switch external port on
          vWait25(200);                // wait for 5 s
       }
       else{
           for (i=0;i<5;i++)          // wrong sequence
           {
             P9L = LED_segout(0xf);  // LED on
             vWait25(40);            // delay of 1 s
             P9L = 0xff;             // all LEDs off
             vWait25(40);            // delay of 1 s
           }
       }

       for (i=0;i<5;i++){
          ucInput[i] = 0;              // Reset Input Code
       }
       bKeySW1Flag = FALSE;            // Reset status flag KeySW1
       bKeySW2Flag = FALSE;            // Reset status flag KeySW2
       P9L = 0xff;                     // switch all LEDs off
       OUT       = FALSE;              // switch external port off
       i=0;
    }
}
