//==============================================================================
// PROJECT      = H_Line Demonstration Board EB-V850ES/HG2-EE (Code Checker)
// MODULE       = interrupt.c
// SHORT DESC.  = -
// DEVICE       = V850ES/HG2 (uPD70F3707)
// VERSION      = 1.0
// DATE         = 08.11.2005
// LAST CHANGE  = -
// ===========================================================================
// Description:  Entrance code checker
//               The board waits for a predefined sequence of keystrokes
//               (e.g. keySW1-keySW1-keySW2-keySW1-keySW2) and switches the 7seg LED
//               to 'O' and an external port on for 5 s. If the input sequence doesn't
//               match the correct sequence the 7 seg LED flashes 'F' five times.
//               After that the program restart and waits for a new input sequence.
// ===========================================================================
// By:           NEC Electronics (Europe) GmbH
//               Arcadiastrasse 10
//               D-40472 Duesseldorf
//
// =============================================================================

//-----------------------------------------------------------------------------
// Defines
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Include files
//-----------------------------------------------------------------------------
#include "defines.h"

#include <intrinsics.h>
#include "io70f3707.h"


//-----------------------------------------------------------------------------
// Global variables
//-----------------------------------------------------------------------------
extern volatile unsigned char bTimer2Flag;       // Status Flag 16bit Timer two
extern volatile unsigned char bKeySW1Flag;       // Status Flag KeySW1
extern volatile unsigned char bKeySW2Flag;       // Status Flag KeySW2

extern unsigned int uiLEDs;             // LED output


// ============================================================================
//  Module name: vTimer0
//
//  Description:
//               This module is the Interrupt service routine or 16bit Timer one
//
//  Operation:
//
// ============================================================================

#pragma vector = INTTP0CC0_vector
__flat __interrupt void vTimer0(void)
{
    static unsigned char ucFlag;
    static unsigned int uiOldLEDs;
    if ( uiOldLEDs == uiLEDs) {
        if (ucFlag == 0x01) {
            ucFlag = 0x00;
            LED1   = 0xFF;              // LED1 off
            LED2   = 0x01;              // LED2 off
        } else {
            ucFlag = 0x01;
            LED1   = uiLEDs >> 8;       // Output LED1 value
            LED2   = uiLEDs & 0x0001;   // Output LED2 value
        }
    } else {
        uiOldLEDs = uiLEDs;             // save current LED value
        LED1   = uiLEDs >> 8;           // Output LED1 value
        LED2   = uiLEDs & 0x0001;       // Output LED2 value
        ucFlag=0x01;
    }
}



// ============================================================================
//  Module name: vTimer1
//
//  Description:
//               This module is the Interrupt service routine or 16bit Timer two
//
//  Operation:
//               -
// ============================================================================

#pragma vector = INTTP1CC0_vector
__flat __interrupt void vTimer1(void)
{
    bTimer2Flag = 1 ;                   // Set status flag Timer two
}


// ============================================================================
//  Module name: vKeySW2
//
//  Description:
//               This module is the Interrupt service routine for
//               the external interrupt P0 (-> KeySW2)
//
//  Operation:
//               -
// ============================================================================

#pragma vector = INTP0_vector
__flat __interrupt void vKeySW2(void)
{
    bKeySW2Flag = 1 ;                     // Set status flag KeySW2
}


// ============================================================================
//  Module name: vKeySW1
//
//  Description:
//               This module is the Interrupt service routine for
//               the external interrupt P2 (-> KeySW1)
//
//  Operation:
//               -
// ============================================================================

#pragma vector = INTP1_vector
__flat __interrupt void vKeySW1(void)
{
    bKeySW1Flag = 1 ;                     // Set status flag KeySW1
}

