//==============================================================================
// PROJECT      = H_Line Demonstration Board EB-V850ES/HG2-EE (Lightshow)
// MODULE       = init.c
// SHORT DESC.  = -
// DEVICE       = V850ES/HG2 (uPD70F3707)
// VERSION      = 1.0
// DATE         = 08.11.2005
// LAST CHANGE  = -
// ===========================================================================
// Description:  hard/software initialisation for Lightshow
// ===========================================================================
// By:           NEC Electronics (Europe) GmbH
//               Arcadiastrasse 10
//               D-40472 Duesseldorf
//
// =============================================================================

//-----------------------------------------------------------------------------
// Include files
//-----------------------------------------------------------------------------
#include "defines.h"

#include <intrinsics.h>
#include "io70f3707.h"


//-----------------------------------------------------------------------------
// Global variables
//-----------------------------------------------------------------------------
extern volatile unsigned char bTimer3Flag;      // status Flag 16bit Timer three
extern volatile unsigned char bTimer2Flag;      // status Flag 16bit Timer two
extern volatile unsigned char bKeySW1Flag;      // status Flag KeySW1
extern volatile unsigned char bKeySW2Flag;      // status Flag KeySW2


// ============================================================================
//  Module name: vHardwareInit
//
//  Description:
//               This module is to initialize some peripheral hardware.
//
//  Operation:
//               Sets the clock generator, the port modes and output latches
//               and initializes the interrupts.
// ============================================================================

void vHardwareInit(void)               // hardware inizialization
{
// clock generator setting
//------------------------

    VSWC= 0x01;                         // Speedup NPB access
    WDTM2= 0x6F;                        // Use main clock for Watchdog 2

    PRCMD= 0;                           // Set CLK divider to div. by 1
    PCC= 0x00;
    __asm("nop");
    __asm("nop");
    __asm("nop");
    __asm("nop");
    __asm("nop");

    PLLCTL |= 1;                        // Enable PLL
    while (LOCKR)                       // Wait for PLL is locked
        ;

    PLLCTL= 3;                          // Switch to PLL clock (CLK x 4)
    __asm("nop");
    __asm("nop");
    __asm("nop");
    __asm("nop");
    __asm("nop");

    OSTS = 0x05;                        // 2^15/fx ms wait after STOP release by interrupt

// port setting
//-------------
    PMC0   = 0x18;                     // Port P0.3 = INTP0 and P0.4 = INTP1
    PM0    = 0xff;                     // Set Port P0 to input mode
    PFC0   = 0x00;                     // Port P0.3 = INTP0
    PU0    = 0x18;                     // enable pullup resistor for Ports P0.3 and P0.4

    PM9     = 0x00;                     // Set Port P9 to output mode
    P9L     = 0xff;                     // switch LEDs off

// ext. Interrupt setting
// -------------------
    INTF0_bit.no4= INTF0_bit.no3= 0;   // setting ext.interrupt 0, 1: rising edge
    INTR0_bit.no4= INTR0_bit.no3= 1;   //

    PMK0   = 0;                        // enable ext. interrupt 0 (Mask Flag Register)
    PMK1   = 0;                        // enable ext. interrupt 1 (Mask Flag Register)

// 16 Bit Timer P setting
// --------------------
    INITTIMER1;
    INITTIMER2;
}


// ============================================================================
//  Module name: vSoftwareInit
//
//  Description:
//               This module is to initialize the bit variables
//
//  Operation:
//               -
// ============================================================================

void vSoftwareInit(void)
{
    bTimer2Flag  = FALSE;              // reset status flag 16bit Timer two
    bKeySW1Flag  = FALSE;              // reset status flag KeySW1
    bKeySW2Flag  = FALSE;              // reset status flag KeySW2
}

