//==============================================================================
// PROJECT      = H_Line Demonstration Board EB-V850ES/HG2-EE (Lightshow)
// MODULE       = interrupt.c
// SHORT DESC.  = -
// DEVICE       = V850ES/HG2 (uPD70F3707)
// VERSION      = 1.0
// DATE         = 08.11.2005
// LAST CHANGE  = -
// ===========================================================================
// Description:  Interrupt service routines for Lightshow
// ===========================================================================
// By:           NEC Electronics (Europe) GmbH
//               Arcadiastrasse 10
//               D-40472 Duesseldorf
//
// =============================================================================

//-----------------------------------------------------------------------------
// Defines
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Include files
//-----------------------------------------------------------------------------
#include "defines.h"

#include <intrinsics.h>
#include "io70f3707.h"


//-----------------------------------------------------------------------------
// Global variables
//-----------------------------------------------------------------------------
extern volatile unsigned char  bTimer2Flag;      // Status Flag 16bit Timer two
extern volatile unsigned char  bKeySW1Flag;      // Status Flag KeySW1
extern volatile unsigned char  bKeySW2Flag;      // Status Flag KeySW2

extern unsigned char  ucLEDs;           // LED output


// ============================================================================
//  Module name: vTimer0
//
//  Description:
//               This module is the Interrupt service routine or 16bit Timer one
//
//  Operation:
//
// ============================================================================

#pragma vector = INTTP0CC0_vector
__flat __interrupt void vTimer0(void)
{
    static unsigned char ucFlag;
    static unsigned char ucOldLEDs;
    if ( ucOldLEDs == ucLEDs) {
        if (ucFlag==0x01) {
            ucFlag = 0x00;
            LED   = 0xFF;              // LED1 off
        } else {
            ucFlag = 0x01;
            LED    = ucLEDs;           // Output LED value
        }
    } else {
           ucOldLEDs = ucLEDs;         // save current LED value
           LED    = ucLEDs;            // Output LED1 value
           ucFlag = 0x01;
    }
}



// ============================================================================
//  Module name: vTimer1
//
//  Description:
//               This module is the Interrupt service routine or 16bit Timer two
//
//  Operation:
//               -
// ============================================================================

#pragma vector = INTTP1CC0_vector
__flat __interrupt void vTimer1(void)
{
    bTimer2Flag = 1 ;                   // Set status flag Timer two
}


// ============================================================================
//  Module name: vKeySW2
//
//  Description:
//               This module is the Interrupt service routine for
//               the external interrupt P0 (-> KeySW2)
//
//  Operation:
//               -
// ============================================================================

#pragma vector = INTP0_vector
__flat __interrupt void vKeySW2(void)
{
    bKeySW2Flag = 1 ;                     // Set status flag KeySW2
}

// ============================================================================
//  Module name: vKeySW1
//
//  Description:
//               This module is the Interrupt service routine for
//               the external interrupt P1 (-> KeySW1)
//
//  Operation:
//               -
// ============================================================================

#pragma vector = INTP1_vector
__flat __interrupt void vKeySW1(void)
{
    bKeySW1Flag = 1 ;                    // Set status flag KeySW1
}

