//==============================================================================
// PROJECT      = H_Line Demonstration Board EB-V850ES/HG2-EE (Lightshow)
// MODULE       = lshow.c
// SHORT DESC.  = -
// DEVICE       = V850ES/HG2 (uPD70F3707)
// VERSION      = 1.0
// DATE         = 08.11.2005
// LAST CHANGE  = -
// ===========================================================================
// Description: Lightshow
//		This sample programs plays one of five predefined lightshows.
//		After the program-start-signal, the program plays lightshow
//              number one. By pressing KeySW1 the next show is selected.
//              KeySW2 selects the previous show. The actual lightshow is
//              displayed by the 7seg LED.
// ===========================================================================
// By:           NEC Electronics (Europe) GmbH
//               Arcadiastrasse 10
//               D-40472 Duesseldorf
//
// =============================================================================

//-----------------------------------------------------------------------------
// Include files
//-----------------------------------------------------------------------------
#include "defines.h"

#include <intrinsics.h>
#include "io70f3707.h"


//-----------------------------------------------------------------------------
// Function prototyps
//-----------------------------------------------------------------------------
       void   vFlashLED      (unsigned char);  // Flash LED's
       void   vWait25        (unsigned char);  // n *  25ms delay

extern void   vShow1         (void);           // Lightshow 1
extern void   vShow2         (void);           // Lightshow 2
extern void   vShow3         (void);           // Lightshow 3
extern void   vShow4         (void);           // Lightshow 4
extern void   vShow5         (void);           // Lightshow 5
extern void   vHardwareInit  (void);           // Initialization Hardware
extern void   vSoftwareInit  (void);           // Initialization measurement variables

//-----------------------------------------------------------------------------
// Global variables
//-----------------------------------------------------------------------------
volatile unsigned char bTimer2Flag;              // status Flag 16Bit Timer two
volatile unsigned char bKeySW1Flag;              // status Flag KeySW1
volatile unsigned char bKeySW2Flag;              // status Flag KeySW2

unsigned char ucLEDs;                    // LED output

#define SMAX  5

void(* pShow[SMAX])(void)={vShow1,vShow2,vShow3,vShow4,vShow5};  // function-pointer array


// ============================================================================
//  Module name: vFlashLED
//
//  Description:
//               This module flashes all LEDs n times.
//
//  Operation:
//               -
// ============================================================================

void vFlashLED(unsigned char Number)
{
    while(Number>0) {
       ucLEDs = 0x00;                // all LEDs on
       vWait25(20);                  // delay of 500 ms
       ucLEDs = 0xFF;                // all LEDs off
       vWait25(20);                  // delay of 500 ms
       Number--;
    }
    return;
}


// ============================================================================
//  Module name: vWait25
//
//  Description:
//               This module delays the program for n * 25 ms.
//
//  Operation:
//               -
// ============================================================================

void vWait25(unsigned char Number)
{
    bTimer2Flag = 0;                   // reset 16 Timer two Flag
    STARTTIMER2;                       // start Timer two
    while(Number > 0) {
        while(bTimer2Flag == 0){
          __NOP();
          __NOP();
        }
        TRIGGERWD;                     // trigger watchdog
        bTimer2Flag = 0;               // reset 16 Timer two Flag
        Number--;
    }
    STOPTIMER2;                        // stop Timer two
    return;
}


// ============================================================================
//  main function
// ============================================================================

void main( void )
{
    signed char i=0;
    TRIGGERWD;                         // trigger watchdog
    __DI();                            // disable all interrupts
    vHardwareInit();                   // peripheral settings
    vSoftwareInit();                   // variable Initialization
    __EI();                            // enable all interrupts
    STARTTIMER1;                       // start 16bit Timer one
    vFlashLED(2);                      // signal program start
    while(TRUE){
       TRIGGERWD;                      // trigger watchdog
       if(bKeySW1Flag == 1){           // keySW1 pressed ?
          bKeySW1Flag = 0;             // reset status flag keySW1
          if(i < (SMAX-1))
            i++;
          else
            i = 0;
       }
       if(bKeySW2Flag == 1){           // keySW2 pressed ?
          bKeySW2Flag = 0;             // reset status flag keySW2
          if(i > 0)
            i--;
          else
            i = (SMAX-1);
       }
       pShow[i]();                     // call selected show
    }
}
