//==============================================================================
// PROJECT      = H_Line Demonstration Board EB-V850ES/HG2-EE (Lightshow)
// MODULE       = sequences.c
// SHORT DESC.  = -
// DEVICE       = V850ES/HG2 (uPD70F3707)
// VERSION      = 1.0
// DATE         = 08.11.2005
// LAST CHANGE  = -
// ===========================================================================
// Description:  Definition of lightshow sequences
// ===========================================================================
// By:           NEC Electronics (Europe) GmbH
//               Arcadiastrasse 10
//               D-40472 Duesseldorf
//
// =============================================================================

//-----------------------------------------------------------------------------
// Include files
//-----------------------------------------------------------------------------
#include "defines.h"

#include <intrinsics.h>
#include "io70f3707.h"


//-----------------------------------------------------------------------------
// Global variables
//-----------------------------------------------------------------------------
extern unsigned char  ucLEDs;                    // LED output
extern volatile unsigned char  bKeySW1Flag;      // Status Flag KeySW1
extern volatile unsigned char  bKeySW2Flag;      // Status Flag KeySW2

//-----------------------------------------------------------------------------
// Function prototyps
//-----------------------------------------------------------------------------
extern void   vWait25 (unsigned char);  // n *  25ms delay


// ============================================================================
//  Module name: vShow1
//
//  Description:
//               This module defines lightshow number1.
//
//  Operation:
//               -
// ============================================================================

void vShow1(void)
{
    ucLEDs=0x00;
    vWait25(20);                    // Delay of 500 ms
    ucLEDs=0xFF;
    vWait25(20);                    // Delay of 500 ms
    return;
}
// ============================================================================
//  Module name: vShow2
//
//  Description:
//               This module defines lightshow number2.
//
//  Operation:
//               -
// ============================================================================

void vShow2(void)
{
    unsigned char i;
    unsigned char pattern[]={0xFE,0xFC,0xF8,0xF0,0xE0,0xC0,0x80,0x00};
    ucLEDs=0xFF;
    for(i=0;i<8;i++){
      ucLEDs = pattern[i];
      vWait25(20);                    // Delay of 500 ms
      if((bKeySW1Flag == TRUE) || (bKeySW2Flag == TRUE)) return;
    }
    return;
}
// ============================================================================
//  Module name: vShow3
//
//  Description:
//               This module defines lightshow number3.
//
//  Operation:
//               -
// ============================================================================

void vShow3(void)
{
    unsigned char i;
    unsigned char pattern[]={0xFE,0xFD,0xFB,0xF7,0xEF,0xDF};
    ucLEDs=0xFF;
    for(i=0;i<6;i++){
      ucLEDs = pattern[i];
      vWait25(4);                    // Delay of 100 ms
      if((bKeySW1Flag == TRUE) || (bKeySW2Flag == TRUE)) return;
    }
    return;
}

// ============================================================================
//  Module name: vShow4
//
//  Description:
//               This module defines lightshow number4.
//
//  Operation:
//               -
// ============================================================================

void vShow4(void)
{
    unsigned char i;
    unsigned char pattern[]={0xFE,0xFD,0xBF,0xEF,0xF7,0xFB,0xBF,0xDF};
    ucLEDs=0xFF;
    for(i=0;i<8;i++){
      ucLEDs = pattern[i];
      vWait25(4);                    // Delay of 100 ms
      if((bKeySW1Flag == TRUE) || (bKeySW2Flag == TRUE)) return;
    }
    return;
}

// ============================================================================
//  Module name: vShow5
//
//  Description:
//               This module defines lightshow number5.
//
//  Operation:
//               -
// ============================================================================

void vShow5(void)
{
    unsigned char i;
    unsigned char pattern[]={0xBF,0xF9,0xF6,0xCF};
    ucLEDs=0xFF;
    for(i=0;i<4;i++){
      ucLEDs = pattern[i];
      vWait25(8);                    // Delay of 200 ms
      if((bKeySW1Flag == TRUE) || (bKeySW2Flag == TRUE)) return;
    }
    return;
}




