//==============================================================================
// PROJECT      = H_Line Demonstration Board EB-V850ES/HG2-EE (Reaction Timer Measurement)
// MODULE       = reactime.c
// SHORT DESC.  = -
// DEVICE       = V850ES/HG2 (uPD70F3707)
// VERSION      = 1.0
// DATE         = 08.11.2005
// LAST CHANGE  = -
// ===========================================================================
// Description:  Reaction Timer Measurement
//               This sample program demonstrates a reaction time measurement.
//               After a press of button SW1 the boards waits for a random time between 0.50
//               and 3.45 seconds. Then the 7seg LED is switch on and measurement starts.
//               Until the next keystroke of button SW1 every 50 ms the LED value increments.
//               The pressing of button SW2 starts a new measuring cycle.
// ===========================================================================
// By:           NEC Electronics (Europe) GmbH
//               Arcadiastrasse 10
//               D-40472 Duesseldorf
//
// =============================================================================

//-----------------------------------------------------------------------------
// Defines
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Include files
//-----------------------------------------------------------------------------
#include "defines.h"

#include <intrinsics.h>
#include "io70f3707.h"

//-----------------------------------------------------------------------------
// Function prototyps
//-----------------------------------------------------------------------------
       void          vFlashLED      (unsigned char);  // flash ucLEDs's
       void          vWait25        (unsigned char);  // n *  25ms delay
       unsigned char ucRandom       (void);           // generation of random-number
extern void          vHardwareInit  (void);           // initialization Hardware
extern void          vSoftwareInit  (void);           // initialization bit variables

//-----------------------------------------------------------------------------
// Global variables
//-----------------------------------------------------------------------------
volatile unsigned char bTimer2Flag;          // status Flag Timer2
volatile unsigned char bTimer3Flag;          // status Flag Timer3
volatile unsigned char bKeySW1Flag;          // status KeySW1
volatile unsigned char bKeySW2Flag;          // status KeySW2
volatile unsigned char ucLEDs;               // LEDs output

// ============================================================================
//  Module name: LED_segout
//
//  Description:
//               Generates output pattern for 7 seg. LED
//
// ============================================================================
unsigned char LED_segout(unsigned char binary)
{
    const unsigned char tab[16]={0xC0,0xf9,0xa4,0xb0,0x99,0x92,0x82,0xf8,0x80,0x90,0x88,0x83,0xc6,0xa1,0x86,0x8e};
    return tab[binary];
}

// ============================================================================
//  Module name: ucRandom
//
//  Description:
//               This module generates a pseudo-random number.
//
//  Operation:
//               -
// ============================================================================

unsigned char ucRandom(void)
{
    return 2 * ((TP0CNT % 60) + 10);        // pseudo-random number between 20 ... 138
}


// ============================================================================
//  Module name: vFlashLED
//
//  Description:
//               This module flashes all LEDs n times.
//
//  Operation:
//               -
// ============================================================================

void vFlashLED(unsigned char Number)
{
    while(Number>0) {
       ucLEDs=0x00;                    // all LEDs on
       vWait25(20);                    // delay of 500 ms
       ucLEDs=0xFF;                    // all LEDs off
       vWait25(20);                    // delay of 500 ms
       Number--;
    }
    return;
}


// ============================================================================
//  Module name: vWait25
//
//  Description:
//               This module delays the program for n * 50 ms.
//
//  Operation:
//               -
// ============================================================================

void vWait25(unsigned char Number)
{
  bTimer2Flag = FALSE;                 // reset flag timer2
  STARTTIMER2;                         // start Timer2
  while(Number > 0) {
         while(bTimer2Flag == FALSE){  // wait for Timer Interrupt
          __NOP();
          __NOP();
        }
        TRIGGERWD;                     // trigger watchdog
        bTimer2Flag = FALSE;           // reset status flag Timer2
        Number--;
    }
  STOPTIMER2;                          // stop Timer2
  return;
}



// ============================================================================
//  main function
// ============================================================================

void main( void )
{
    unsigned char i;
    __DI();                            // disable all interrupts
    vHardwareInit();                   // peripheral settings
    vSoftwareInit();                   // variable Initialization
    __EI();                            // enable all interrupts
    STARTTIMER1;                       // start Timer 1
    while(TRUE)
    {
       vFlashLED(2);                   // signal Program start
       TRIGGERWD;                      // trigger watchdog
       if(bKeySW1Flag==1){             // wait for key-stroke of KeySW1
           vWait25(ucRandom());        // wait a random time 0.50 ... 3.45 s
           STARTTIMER2;                // start Timer2
           ucLEDs=0xFE;                //
           bKeySW1Flag=0;              // reset KeySW1 Flag
           i=0;
           while ((i<9)&& bKeySW1Flag==0){
              vWait25(2);              // wait 50ms
              ucLEDs = LED_segout(i);  // switch next LED on
              i++;
           }
           bKeySW2Flag=0;              // Reset KeySW2 Flag
           while(bKeySW2Flag==0){      // Wait for key stroke of KeySW2
              TRIGGERWD;               // trigger watchdog
           }
           ucLEDs=0xFF;                // Clear all LEDs
           bKeySW1Flag=0;              // Reset KeySW1 Flag
           bKeySW2Flag=0;              // Reset KeySW2 Flag
       }
    }
}
